@@ -17,8 +17,8 @@ package Dist::Zilla::Role::HashDumper;
 # ABSTRACT: Dump selected hash keys as a string
 #---------------------------------------------------------------------
 
-our $VERSION = '4.03';
-# This file is part of Dist-Zilla-Plugins-CJM 4.12 (January 12, 2013)
+our $VERSION = '4.13';
+# This file is part of Dist-Zilla-Plugins-CJM 4.13 (April 4, 2013)
 
 use Moose::Role;
 
@@ -49,6 +49,14 @@ sub hash_as_string
 
 
 sub extract_keys
+{
+  my $self = shift;
+
+  return $self->hash_as_string( $self->extract_keys_as_hash(@_) );
+} # end extract_keys
+
+
+sub extract_keys_as_hash
 {
   my $self = shift;
   my $type = shift;
@@ -70,8 +78,8 @@ sub extract_keys
     $want{$key} = $hash->{$key};
   } # end foreach $key
 
-  return $self->hash_as_string(\%want);
-} # end _extract_keys
+  return \%want;
+} # end extract_keys_as_hash
 
 no Moose::Role;
 1;
@@ -84,9 +92,9 @@ Dist::Zilla::Role::HashDumper - Dump selected hash keys as a string
 
 =head1 VERSION
 
-This document describes version 4.03 of
-Dist::Zilla::Role::HashDumper, released January 12, 2013
-as part of Dist-Zilla-Plugins-CJM version 4.12.
+This document describes version 4.13 of
+Dist::Zilla::Role::HashDumper, released April 4, 2013
+as part of Dist-Zilla-Plugins-CJM version 4.13.
 
 =head1 DESCRIPTION
 
@@ -102,7 +110,8 @@ C<hash_as_string> method to do the same for an entire hash.
   my $string = $plugin->extract_keys($name, \%hash, @keys);
   eval "%new_hash = ($string);";
 
-This constructs a string of properly quoted keys and values from a
+This combines C<extract_keys_as_hash> and C<hash_as_string>.
+It constructs a string of properly quoted keys and values from
 selected keys in a hash.  (Note that C<\%hash> is a reference, but
 C<@keys> is not.)  The C<$name> is used only in a log_debug message.
 
@@ -111,6 +120,19 @@ it will be omitted from the list.  If all keys are omitted, the empty
 string is returned.  Otherwise, the result always ends with a comma.
 
 
+=head2 extract_keys_as_hash
+
+  my $hashref = $plugin->extract_keys_as_hash($name, \%hash, @keys);
+
+This constructs a hashref from from selected keys in a hash.  (Note
+that C<\%hash> is a reference, but C<@keys> is not.)  The C<$name> is
+used only in a log_debug message.
+
+If any key has no value (or its value is an empty hash or array ref)
+it will be omitted from the new hashref.  If all keys are omitted,
+an empty hashref is returned.
+
+
 =head2 hash_as_string
 
   my $string = $plugin->hash_as_string(\%hash);
